@@ -13,7 +13,7 @@
     delay setting.  The use of higher order Lagrange interpolators can
     typically improve (minimize) this attenuation characteristic.
 
-    by Perry R. Cook and Gary P. Scavone, 1995 - 2010.
+    by Perry R. Cook and Gary P. Scavone, 1995-2011.
 */
 /***************************************************/
 
@@ -23,13 +23,13 @@ namespace stk {
 
 DelayL :: DelayL( StkFloat delay, unsigned long maxDelay )
 {
-  if ( delay < 0.0 || maxDelay < 1 ) {
-    errorString_ << "DelayL::DelayL: delay must be >= 0.0, maxDelay must be > 0!";
+  if ( delay < 0.0 ) {
+    oStream_ << "DelayL::DelayL: delay must be >= 0.0!";
     handleError( StkError::FUNCTION_ARGUMENT );
   }
 
   if ( delay > (StkFloat) maxDelay ) {
-    errorString_ << "DelayL::DelayL: maxDelay must be > than delay argument!";
+    oStream_ << "DelayL::DelayL: maxDelay must be > than delay argument!";
     handleError( StkError::FUNCTION_ARGUMENT );
   }
 
@@ -49,46 +49,25 @@ DelayL :: ~DelayL()
 void DelayL :: setMaximumDelay( unsigned long delay )
 {
   if ( delay < inputs_.size() ) return;
-
-  if ( delay < 0 ) {
-    errorString_ << "DelayL::setMaximumDelay: argument (" << delay << ") less than zero!\n";
-    handleError( StkError::WARNING );
-    return;
-  }
-  else if ( delay < delay_ ) {
-    errorString_ << "DelayL::setMaximumDelay: argument (" << delay << ") less than current delay setting (" << delay_ << ")!\n";
-    handleError( StkError::WARNING );
-    return;
-  }
-
   inputs_.resize( delay + 1 );
 }
 
 void DelayL :: setDelay( StkFloat delay )
 {
-  StkFloat outPointer;
-
   if ( delay + 1 > inputs_.size() ) { // The value is too big.
-    errorString_ << "DelayL::setDelay: argument (" << delay << ") too big ... setting to maximum!";
-    handleError( StkError::WARNING );
-
-    // Force delay to maxLength
-    outPointer = inPoint_ + 1.0;
-    delay_ = inputs_.size() - 1;
-  }
-  else if (delay < 0 ) {
-    errorString_ << "DelayL::setDelay: argument (" << delay << ") less than zero ... setting to zero!";
-    handleError( StkError::WARNING );
-
-    outPointer = inPoint_;
-    delay_ = 0;
-  }
-  else {
-    outPointer = inPoint_ - delay;  // read chases write
-    delay_ = delay;
+    oStream_ << "DelayL::setDelay: argument (" << delay << ") greater than  maximum!";
+    handleError( StkError::WARNING ); return;
   }
 
-  while (outPointer < 0)
+  if (delay < 0 ) {
+    oStream_ << "DelayL::setDelay: argument (" << delay << ") less than zero!";
+    handleError( StkError::WARNING ); return;
+  }
+
+  StkFloat outPointer = inPoint_ - delay;  // read chases write
+  delay_ = delay;
+
+  while ( outPointer < 0 )
     outPointer += inputs_.size(); // modulo maximum length
 
   outPoint_ = (long) outPointer;   // integer part
@@ -97,7 +76,7 @@ void DelayL :: setDelay( StkFloat delay )
   omAlpha_ = (StkFloat) 1.0 - alpha_;
 }
 
-StkFloat DelayL :: contentsAt( unsigned long tapDelay )
+StkFloat DelayL :: tapOut( unsigned long tapDelay )
 {
   long tap = inPoint_ - tapDelay - 1;
   while ( tap < 0 ) // Check for wraparound.
@@ -106,4 +85,13 @@ StkFloat DelayL :: contentsAt( unsigned long tapDelay )
   return inputs_[tap];
 }
 
+void DelayL :: tapIn( StkFloat value, unsigned long tapDelay )
+{
+  long tap = inPoint_ - tapDelay - 1;
+  while ( tap < 0 ) // Check for wraparound.
+    tap += inputs_.size();
+
+  inputs_[tap] = value;
+}
+
 } // stk namespace
